summaryrefslogtreecommitdiff
path: root/sfx2/inc/sfx2/childwin.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sfx2/inc/sfx2/childwin.hxx')
-rw-r--r--sfx2/inc/sfx2/childwin.hxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/sfx2/inc/sfx2/childwin.hxx b/sfx2/inc/sfx2/childwin.hxx
index fd1eb65d54df..5570506b2c89 100644
--- a/sfx2/inc/sfx2/childwin.hxx
+++ b/sfx2/inc/sfx2/childwin.hxx
@@ -164,7 +164,7 @@ public:
virtual void Resizing( Size& rSize );
virtual sal_Bool Close();
- static void RegisterChildWindowContext(SfxModule*, USHORT, SfxChildWinContextFactory*);
+ static void RegisterChildWindowContext(SfxModule*, sal_uInt16, SfxChildWinContextFactory*);
};
class SFX2_DLLPUBLIC SfxChildWindow
@@ -204,7 +204,7 @@ public:
{ return pWindow->GetPosPixel(); }
//<!--Modified by PengYunQuan for Validity Cell Range Picker
virtual void Hide();
- virtual void Show( USHORT nFlags );
+ virtual void Show( sal_uInt16 nFlags );
//-->Modified by PengYunQuan for Validity Cell Range Picker
sal_uInt16 GetFlags() const
{ return GetInfo().nFlags; }
@@ -233,7 +233,7 @@ public:
void SetHideAtToggle( sal_Bool bOn );
sal_Bool IsHideAtToggle() const;
sal_Bool IsVisible() const;
- void SetWantsFocus( BOOL );
+ void SetWantsFocus( sal_Bool );
sal_Bool WantsFocus() const;
virtual sal_Bool QueryClose();
@@ -274,7 +274,7 @@ public:
SfxBindings *pBindings, SfxChildWinInfo* pInfo ) \
{ \
SfxChildWindowContext *pContext = new Class(pParent, \
/* cast is safe here! */static_cast< USHORT >(ShellClass::GetInterfaceId()), \
pBindings,pInfo); \
return pContext; \
} \
@@ -274,7 +274,7 @@ public:
{ \
SfxChildWindowContext *pContext = new Class(pParent, \
- /* cast is safe here! */static_cast< USHORT >(ShellClass::GetInterfaceId()), \
+ /* cast is safe here! */static_cast< sal_uInt16 >(ShellClass::GetInterfaceId()), \
pBindings,pInfo); \
return pContext; \